@@ -14,17 +14,13 @@ OKDATA_CONFIG["dev"] = {
     "cacheCredentials": False,
     "dataExporterUrl": "https://api.data-dev.oslo.systems/data-exporter",
     "datasetUrl": "https://api.data-dev.oslo.systems/metadata/datasets",
-    "elasticsearchQueryUrl": "https://api.data-dev.oslo.systems/elasticsearch-queries",
-    "eventCollectorUrl": "https://api.data-dev.oslo.systems/event-collector",
     "keycloakRealm": "api-catalog",
     "keycloakServerUrl": "https://login-test.oslo.kommune.no/auth",
     "pipelineUrl": "https://api.data-dev.oslo.systems/pipeline",
     "s3BucketUrl": "https://s3.eu-west-1.amazonaws.com/ok-origo-dataplatform-dev",
-    "eventStreamUrl": "https://api.data-dev.oslo.systems/streams",
     "tokenService": "https://api.data-dev.oslo.systems/token-service/token",
     "uploadUrl": "https://api.data-dev.oslo.systems/data-uploader",
     "statusApiUrl": "https://api.data-dev.oslo.systems/status-api/status",
-    "simpleDatasetAuthorizerUrl": "https://api.data-dev.oslo.systems/simple-dataset-authorizer",
     "permissionApiUrl": "https://api.data-dev.oslo.systems/okdata-permission-api",
 }
 OKDATA_CONFIG["prod"] = {
@@ -33,17 +29,13 @@ OKDATA_CONFIG["prod"] = {
     "cacheCredentials": False,
     "dataExporterUrl": "https://api.data.oslo.systems/data-exporter",
     "datasetUrl": "https://api.data.oslo.systems/metadata/datasets",
-    "elasticsearchQueryUrl": "https://api.data.oslo.systems/elasticsearch-queries",
-    "eventCollectorUrl": "https://api.data.oslo.systems/event-collector",
     "keycloakRealm": "api-catalog",
     "keycloakServerUrl": "https://login.oslo.kommune.no/auth",
     "pipelineUrl": "https://api.data.oslo.systems/pipeline",
     "s3BucketUrl": "https://s3.eu-west-1.amazonaws.com/ok-origo-dataplatform-prod",
-    "eventStreamUrl": "https://api.data.oslo.systems/streams",
     "tokenService": "https://api.data.oslo.systems/token-service/token",
     "uploadUrl": "https://api.data.oslo.systems/data-uploader",
     "statusApiUrl": "https://api.data.oslo.systems/status-api/status",
-    "simpleDatasetAuthorizerUrl": "https://api.data.oslo.systems/simple-dataset-authorizer",
     "permissionApiUrl": "https://api.data.oslo.systems/okdata-permission-api",
 }
 
