@@ -12,13 +12,13 @@ class Status(SDK):
 
     def get_status(self, uuid, retries=0):
         url = self.config.get("statusApiUrl")
-        log.info(f"Retrieving status for UUID={uuid} from: {url}")
+        log.info(f"Retrieving status for UUID={uuid} from: {url}")
         response = self.get(f"{url}/{uuid}", retries=retries)
-        if response.status_code == 200:
-            return response.json()
         response.raise_for_status()
+        return response.json()
 
     def update_status(self, trace_id, data, retries=0):
         url = self.config.get("statusApiUrl")
         response = self.post(f"{url}/{trace_id}", data, retries=retries)
+        response.raise_for_status()
         return response.json()
